print("import: 'urllib3'")
import urllib3

print("import: 'urllib3.contrib'")
import urllib3.contrib

print("import: 'urllib3.packages'")
import urllib3.packages

print("import: 'urllib3.packages.backports'")
import urllib3.packages.backports

print("import: 'urllib3.packages.ssl_match_hostname'")
import urllib3.packages.ssl_match_hostname

print("import: 'urllib3.util'")
import urllib3.util

